aboutsummaryrefslogtreecommitdiff
path: root/tests/torture.c
diff options
context:
space:
mode:
authorAndreas Schneider <asn@cryptomilk.org>2018-06-30 14:59:11 +0200
committerAndreas Schneider <asn@cryptomilk.org>2018-06-30 15:27:09 +0200
commitf4408f38a3a0b0803daa0dc3e44df79291f52c87 (patch)
tree302be05a398ed681648a91389509dc84c1a685e4 /tests/torture.c
parent6dd9303729b430af3eaf1014af5af99c9230e9c7 (diff)
downloadlibssh-f4408f38a3a0b0803daa0dc3e44df79291f52c87.tar.gz
libssh-f4408f38a3a0b0803daa0dc3e44df79291f52c87.tar.xz
libssh-f4408f38a3a0b0803daa0dc3e44df79291f52c87.zip
torture: Give sshd at least 100ms to start.
This should avoid some 'No route to host' errors. Signed-off-by: Andreas Schneider <asn@cryptomilk.org>
Diffstat (limited to 'tests/torture.c')
-rw-r--r--tests/torture.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/torture.c b/tests/torture.c
index 9fe4ce77..3640f78c 100644
--- a/tests/torture.c
+++ b/tests/torture.c
@@ -725,8 +725,8 @@ void torture_setup_sshd_server(void **state)
rc = system(sshd_start_cmd);
assert_return_code(rc, errno);
- /* Give the process some time to start */
- usleep(10000);
+ /* Give the process 100ms time to initialize and start */
+ usleep(100 * 1000);
setenv("SOCKET_WRAPPER_DEFAULT_IFACE", "21", 1);
unsetenv("PAM_WRAPPER");